==> pyfastnet-1.0.10-py3-none-any.whl: fastnet_decoder/mappings.py <==
ADDRESS_LOOKUP = {
    0xFA: "All 20/20s",
    0xFB: "All Halcyon FFDs",
    0xFC: "All Pilot FFDs",
    0xFD: "All Processor Nodes",
    0xFE: "All FFDs",
    0xFF: "Entire System",
    
    0x01: "Normal CPU (Depth Board in H2000)",
    0x05: "Normal CPU (Wind Board in H2000)",
    0x09: "Performance Processor",
    
    0x0D: "Expansion Unit",
    0x0E: "Expansion Unit",
    0x0F: "Expansion Unit",
    
    0x10: "Halcyon 2000 Compass (Directly Connected to FastNet Bus)",
    0x11: "Halcyon Gyro-Stabilised Compass (via ACP)",
    0x12: "Halcyon Gyro-Stabilised Compass (via Pilot ACP)",
    
    # FastNet Display Groups
    0x20: "FFD (20)",
    0x21: "FFD (21)",
    0x22: "FFD (22)",
    0x23: "FFD (23)",
    0x24: "FFD (24)",
    0x25: "FFD (25)",
    0x26: "FFD (26)",
    0x27: "FFD (27)",
    0x28: "FFD (28)",
    0x29: "FFD (29)",
    0x2A: "FFD (2A)",
    0x2B: "FFD (2B)",
    0x2C: "FFD (2C)",
    0x2D: "FFD (2D)",
    0x2E: "FFD (2E)",
    0x2F: "FFD (2F)",
    
    # Halcyon FFD Group
    0x30: "Halcyon FFD (30)",
    0x31: "Halcyon FFD (31)",
    0x32: "Halcyon FFD (32)",
    0x33: "Halcyon FFD (33)",
    0x34: "Halcyon FFD (34)",
    0x35: "Halcyon FFD (35)",
    0x36: "Halcyon FFD (36)",
    0x37: "Halcyon FFD (37)",
    0x38: "Halcyon FFD (38)",
    0x39: "Halcyon FFD (39)",
    0x3A: "Halcyon FFD (3A)",
    0x3B: "Halcyon FFD (3B)",
    0x3C: "Halcyon FFD (3C)",
    0x3D: "Halcyon FFD (3D)",
    0x3E: "Halcyon FFD (3E)",
    0x3F: "Halcyon FFD (3F)",

    # Display 20/20 Group
    0x40: "Display 20/20 (40)",
    0x41: "Display 20/20 (41)",
    0x42: "Display 20/20 (42)",
    0x43: "Display 20/20 (43)",
    0x44: "Display 20/20 (44)",
    0x45: "Display 20/20 (45)",
    0x46: "Display 20/20 (46)",
    0x47: "Display 20/20 (47)",
    
    # Pilot FFD Group
    0x50: "Pilot FFD (50)",
    0x51: "Pilot FFD (51)",
    0x52: "Pilot FFD (52)",
    0x53: "Pilot FFD (53)",
    0x54: "Pilot FFD (54)",
    0x55: "Pilot FFD (55)",
    0x56: "Pilot FFD (56)",
    0x57: "Pilot FFD (57)",
    0x58: "Pilot FFD (58)",
    0x59: "Pilot FFD (59)",
    0x5A: "Pilot FFD (5A)",
    0x5B: "Pilot FFD (5B)",
    0x5C: "Pilot FFD (5C)",
    0x5D: "Pilot FFD (5D)",
    0x5E: "Pilot FFD (5E)",
    0x5F: "Pilot FFD (5F)",
    
    # External Compass
    0x60: "External Compass (NMEA FFD 60)",
    0x61: "External Compass (NMEA FFD 61)",
    0x62: "External Compass (NMEA FFD 62)",
    0x63: "External Compass (NMEA FFD 63)",
    0x64: "External Compass (NMEA FFD 64)",
    0x65: "External Compass (NMEA FFD 65)",
    0x66: "External Compass (NMEA FFD 66)",
    0x67: "External Compass (NMEA FFD 67)",
    0x68: "External Compass (NMEA FFD 68)",
    0x69: "External Compass (NMEA FFD 69)",
    0x6A: "External Compass (NMEA FFD 6A)",
    0x6B: "External Compass (NMEA FFD 6B)",
    0x6C: "External Compass (NMEA FFD 6C)",
    0x6D: "External Compass (NMEA FFD 6D)",
    0x6E: "External Compass (NMEA FFD 6E)",
    0x6F: "External Compass (NMEA FFD 6F)"
}

COMMAND_LOOKUP = {
    0x01: "Broadcast",
    0x0C: "Keep Alive",
    0x03: "LatLon",
    0xC9: "Light Intensity",
}


CHANNEL_LOOKUP = {
    0x00: "Node Reset",
    0x0B: "Rudder Angle",
    0x1C: "Air Temperature (°F)",
    0x1D: "Air Temperature (°C)",
    0x1E: "Sea Temperature (°F)",
    0x1F: "Sea Temperature (°C)",
    0x27: "Head/Lift Trend",
    0x29: "Off Course",
    0x32: "Tacking Performance",
    0x33: "Reaching Performance",
    0x34: "Heel Angle",
    0x35: "Optimum Wind Angle",
    0x36: "Depth Sounder Receiver Gain",
    0x37: "Depth Sounder Noise",
    0x3B: "Linear 4",
    0x3C: "Rate Motion",
    0x41: "Boatspeed (Knots)",
    0x42: "Boatspeed (Raw)",
    0x46: "Autopilot Speed Fixed (Knots)",
    0x47: "LatLon",
    0x49: "Heading",
    0x4A: "Heading (Raw)",
    0x4D: "Apparent Wind Speed (Knots)",
    0x4E: "Apparent Wind Speed (Raw)",
    0x4F: "Apparent Wind Speed (m/s)",
    0x51: "Apparent Wind Angle",
    0x52: "Apparent Wind Angle (Raw)",
    0x53: "Autopilot Target TWA",
    0x55: "True Wind Speed (Knots)",
    0x56: "True Wind Speed (m/s)",
    0x57: "Measured Wind Speed (Knots)",
    0x59: "True Wind Angle",
    0x5A: "Measured Wind Angle Deg",
    0x64: "Average Speed (Knots)",
    0x65: "Aberage Speed (raw)",
    0x69: "Course",
    0x6D: "True Wind Direction",
    0x6F: "Next Leg Apparent Wind Angle",
    0x70: "Next Leg Target Boat Speed",
    0x71: "Next Leg Apparent Wind Speed",
    0x75: "Timer",
    0x7D: "Target Boatspeed",
    0x7F: "Velocity Made Good (Knots)",
    0x81: "Dead Reckoning Distance",
    0x82: "Leeway",
    0x83: "Tidal Drift",
    0x84: "Tidal Set",
    0x85: "Upwash",
    0x86: "Barometric Pressure Trend",
    0x87: "Barometric Pressure",
    0x8D: "Battery Volts",
    0x9A: "Heading on Next Tack",
    0x9B: "Fore/Aft Trim",
    0x9C: "Mast Angle",
    0x9D: "Wind Angle to the Mast",
    0x9E: "Pitch Rate (Motion)",
    0xA6: "Autopilot Compass Target",
    0xAF: "Autopilot Off Course",
    0xC1: "Depth (Meters)",
    0xC2: "Depth (Feet)",
    0xC3: "Depth (Fathoms)",
    0xCD: "Stored Log (NM)",
    0xCF: "Trip Log (NM)",
    0xDC: "Local Time",
    0xD3: "Dead Reckoning Course",
    0xE0: "Bearing Wpt. to Wpt. (True)",
    0xE1: "Bearing Wpt. to Wpt. (Mag)",
    0xE2: "Layline Distance",
    0xE3: "Bearing to Waypoint (Rhumb True)",
    0xE4: "Bearing to Waypoint (Rhumb Mag)",
    0xE5: "Bearing to Waypoint (G.C. True)",
    0xE6: "Bearing to Waypoint (G.C. Mag)",
    0xE7: "Distance to Waypoint (Rhumb)",
    0xE8: "Distance to Waypoint (G.C.)",
    0xE9: "Course Over Ground (True)",
    0xEA: "Course Over Ground (Mag)",
    0xEB: "Speed Over Ground",
    0xEC: "VMG to Waypoint (VMC)",
    0xED: "Time to Waypoint",
    0xEE: "Cross Track Error",
    0xEF: "Remote 0",
    0xF0: "Remote 1",
    0xF1: "Remote 2",
    0xF2: "Remote 3",
    0xF3: "Remote 4",
    0xF4: "Remote 5",
    0xF5: "Remote 6",
    0xF6: "Remote 7",
    0xF7: "Remote 8",
    0xF8: "Remote 9",
    0xFA: "Next Waypoint Distance",
    0xFB: "Time to Layline"
}


FORMAT_SIZE_MAP = {
    0x00: 4,  # 32 bits (4 bytes)
    0x01: 2,  # 16 bits (2 bytes)
    0x02: 2,  # 16 bits (2 bytes)
    0x03: 2,  # 16 bits (2 bytes)
    0x04: 4,  # 32 bits (4 bytes)
    0x05: 4,  # 32 bits (4 bytes)
    0x06: 4,  # 16 bits (2 bytes)
    0x07: 4,  # 16 bits (2 bytes)
    0x08: 2,  # 16 bits (2 bytes)
    0x0A: 4   # 32 bits (4 bytes)
}

==> pyfastnet-1.0.17-py3-none-any.whl: fastnet_decoder/mappings.py <==
ADDRESS_LOOKUP = {
    0xFA: "All 20/20s",
    0xFB: "All Halcyon FFDs",
    0xFC: "All Pilot FFDs",
    0xFD: "All Processor Nodes",
    0xFE: "All FFDs",
    0xFF: "Entire System",
    
    0x01: "Normal CPU (Depth Board in H2000)",
    0x05: "Normal CPU (Wind Board in H2000)",
    0x09: "Performance Processor",
    
    0x0D: "Expansion Unit",
    0x0E: "Expansion Unit",
    0x0F: "Expansion Unit",
    
    0x10: "Halcyon 2000 Compass (Directly Connected to FastNet Bus)",
    0x11: "Halcyon Gyro-Stabilised Compass (via ACP)",
    0x12: "Halcyon Gyro-Stabilised Compass (via Pilot ACP)",
    
    # FastNet Display Groups
    0x20: "FFD (20)",
    0x21: "FFD (21)",
    0x22: "FFD (22)",
    0x23: "FFD (23)",
    0x24: "FFD (24)",
    0x25: "FFD (25)",
    0x26: "FFD (26)",
    0x27: "FFD (27)",
    0x28: "FFD (28)",
    0x29: "FFD (29)",
    0x2A: "FFD (2A)",
    0x2B: "FFD (2B)",
    0x2C: "FFD (2C)",
    0x2D: "FFD (2D)",
    0x2E: "FFD (2E)",
    0x2F: "FFD (2F)",
    
    # Halcyon FFD Group
    0x30: "Halcyon FFD (30)",
    0x31: "Halcyon FFD (31)",
    0x32: "Halcyon FFD (32)",
    0x33: "Halcyon FFD (33)",
    0x34: "Halcyon FFD (34)",
    0x35: "Halcyon FFD (35)",
    0x36: "Halcyon FFD (36)",
    0x37: "Halcyon FFD (37)",
    0x38: "Halcyon FFD (38)",
    0x39: "Halcyon FFD (39)",
    0x3A: "Halcyon FFD (3A)",
    0x3B: "Halcyon FFD (3B)",
    0x3C: "Halcyon FFD (3C)",
    0x3D: "Halcyon FFD (3D)",
    0x3E: "Halcyon FFD (3E)",
    0x3F: "Halcyon FFD (3F)",

    # Display 20/20 Group
    0x40: "Display 20/20 (40)",
    0x41: "Display 20/20 (41)",
    0x42: "Display 20/20 (42)",
    0x43: "Display 20/20 (43)",
    0x44: "Display 20/20 (44)",
    0x45: "Display 20/20 (45)",
    0x46: "Display 20/20 (46)",
    0x47: "Display 20/20 (47)",
    
    # Pilot FFD Group
    0x50: "Pilot FFD (50)",
    0x51: "Pilot FFD (51)",
    0x52: "Pilot FFD (52)",
    0x53: "Pilot FFD (53)",
    0x54: "Pilot FFD (54)",
    0x55: "Pilot FFD (55)",
    0x56: "Pilot FFD (56)",
    0x57: "Pilot FFD (57)",
    0x58: "Pilot FFD (58)",
    0x59: "Pilot FFD (59)",
    0x5A: "Pilot FFD (5A)",
    0x5B: "Pilot FFD (5B)",
    0x5C: "Pilot FFD (5C)",
    0x5D: "Pilot FFD (5D)",
    0x5E: "Pilot FFD (5E)",
    0x5F: "Pilot FFD (5F)",
    
    # External Compass
    0x60: "External Compass (NMEA FFD 60)",
    0x61: "External Compass (NMEA FFD 61)",
    0x62: "External Compass (NMEA FFD 62)",
    0x63: "External Compass (NMEA FFD 63)",
    0x64: "External Compass (NMEA FFD 64)",
    0x65: "External Compass (NMEA FFD 65)",
    0x66: "External Compass (NMEA FFD 66)",
    0x67: "External Compass (NMEA FFD 67)",
    0x68: "External Compass (NMEA FFD 68)",
    0x69: "External Compass (NMEA FFD 69)",
    0x6A: "External Compass (NMEA FFD 6A)",
    0x6B: "External Compass (NMEA FFD 6B)",
    0x6C: "External Compass (NMEA FFD 6C)",
    0x6D: "External Compass (NMEA FFD 6D)",
    0x6E: "External Compass (NMEA FFD 6E)",
    0x6F: "External Compass (NMEA FFD 6F)"
}

COMMAND_LOOKUP = {
    0x01: "Broadcast",
    0x0C: "Keep Alive",
    0x03: "LatLon",
    0xC9: "Light Intensity",
}


CHANNEL_LOOKUP = {
    0x00: "Node Reset",
    0x0B: "Rudder Angle",
    0x1C: "Air Temperature (°F)",
    0x1D: "Air Temperature (°C)",
    0x1E: "Sea Temperature (°F)",
    0x1F: "Sea Temperature (°C)",
    0x27: "Head/Lift Trend",
    0x29: "Off Course",
    0x32: "Tacking Performance",
    0x33: "Reaching Performance",
    0x34: "Heel Angle",
    0x35: "Optimum Wind Angle",
    0x36: "Depth Sounder Receiver Gain",
    0x37: "Depth Sounder Noise",
    0x3B: "Linear 4",
    0x3C: "Rate Motion",
    0x41: "Boatspeed (Knots)",
    0x42: "Boatspeed (Raw)",
    0x46: "Autopilot Speed Fixed (Knots)",
    0x47: "LatLon",
    0x49: "Heading",
    0x4A: "Heading (Raw)",
    0x4D: "Apparent Wind Speed (Knots)",
    0x4E: "Measured Wind Speed (Raw)",
    0x4F: "Apparent Wind Speed (m/s)",
    0x51: "Apparent Wind Angle",
    0x52: "Measured Wind Angle (Raw)",
    0x53: "Autopilot Target TWA",
    0x55: "True Wind Speed (Knots)",
    0x56: "True Wind Speed (m/s)",
    0x57: "Measured Wind Speed (Knots)",
    0x59: "True Wind Angle",
    0x5A: "Measured Wind Angle Deg",
    0x64: "Average Speed (Knots)",
    0x65: "Aberage Speed (raw)",
    0x69: "Course",
    0x6D: "True Wind Direction",
    0x6F: "Next Leg Apparent Wind Angle",
    0x70: "Next Leg Target Boat Speed",
    0x71: "Next Leg Apparent Wind Speed",
    0x75: "Timer",
    0x7D: "Target Boatspeed",
    0x7F: "Velocity Made Good (Knots)",
    0x81: "Dead Reckoning Distance",
    0x82: "Leeway",
    0x83: "Tidal Drift",
    0x84: "Tidal Set",
    0x85: "Upwash",
    0x86: "Barometric Pressure Trend",
    0x87: "Barometric Pressure",
    0x8D: "Battery Volts",
    0x9A: "Heading on Next Tack",
    0x9B: "Fore/Aft Trim",
    0x9C: "Mast Angle",
    0x9D: "Wind Angle to the Mast",
    0x9E: "Pitch Rate (Motion)",
    0xA6: "Autopilot Compass Target",
    0xAF: "Autopilot Off Course",
    0xC1: "Depth (Meters)",
    0xC2: "Depth (Feet)",
    0xC3: "Depth (Fathoms)",
    0xCD: "Stored Log (NM)",
    0xCF: "Trip Log (NM)",
    0xDC: "Local Time",
    0xD3: "Dead Reckoning Course",
    0xE0: "Bearing Wpt. to Wpt. (True)",
    0xE1: "Bearing Wpt. to Wpt. (Mag)",
    0xE2: "Layline Distance",
    0xE3: "Bearing to Waypoint (Rhumb True)",
    0xE4: "Bearing to Waypoint (Rhumb Mag)",
    0xE5: "Bearing to Waypoint (G.C. True)",
    0xE6: "Bearing to Waypoint (G.C. Mag)",
    0xE7: "Distance to Waypoint (Rhumb)",
    0xE8: "Distance to Waypoint (G.C.)",
    0xE9: "Course Over Ground (True)",
    0xEA: "Course Over Ground (Mag)",
    0xEB: "Speed Over Ground",
    0xEC: "VMG to Waypoint (VMC)",
    0xED: "Time to Waypoint",
    0xEE: "Cross Track Error",
    0xEF: "Remote 0",
    0xF0: "Remote 1",
    0xF1: "Remote 2",
    0xF2: "Remote 3",
    0xF3: "Remote 4",
    0xF4: "Remote 5",
    0xF5: "Remote 6",
    0xF6: "Remote 7",
    0xF7: "Remote 8",
    0xF8: "Remote 9",
    0xFA: "Next Waypoint Distance",
    0xFB: "Time to Layline"
}


FORMAT_SIZE_MAP = {
    0x00: 4,  # 32 bits (4 bytes)
    0x01: 2,  # 16 bits (2 bytes)
    0x02: 2,  # 16 bits (2 bytes)
    0x03: 2,  # 16 bits (2 bytes)
    0x04: 4,  # 32 bits (4 bytes)
    0x05: 4,  # 32 bits (4 bytes)
    0x06: 4,  # 16 bits (2 bytes)
    0x07: 4,  # 16 bits (2 bytes)
    0x08: 2,  # 16 bits (2 bytes)
    0x0A: 4   # 32 bits (4 bytes)
}
